0.9.9 API documentation: type_precision.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

type_precision.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../gtc/quaternion.hpp"
18 #include "../gtc/vec1.hpp"
19 #include "../ext/scalar_int_sized.hpp"
20 #include "../ext/scalar_uint_sized.hpp"
21 #include "../detail/type_vec2.hpp"
22 #include "../detail/type_vec3.hpp"
23 #include "../detail/type_vec4.hpp"
24 #include "../detail/type_mat2x2.hpp"
25 #include "../detail/type_mat2x3.hpp"
26 #include "../detail/type_mat2x4.hpp"
27 #include "../detail/type_mat3x2.hpp"
28 #include "../detail/type_mat3x3.hpp"
29 #include "../detail/type_mat3x4.hpp"
30 #include "../detail/type_mat4x2.hpp"
31 #include "../detail/type_mat4x3.hpp"
32 #include "../detail/type_mat4x4.hpp"
33
34 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
35 # pragma message("GLM: GLM_GTC_type_precision extension included")
36 #endif
37
38 namespace glm
39 {
41 // Signed int vector types
42
45
48 typedef detail::int8 lowp_int8;
49
52 typedef detail::int16 lowp_int16;
53
56 typedef detail::int32 lowp_int32;
57
60 typedef detail::int64 lowp_int64;
61
64 typedef detail::int8 lowp_int8_t;
65
68 typedef detail::int16 lowp_int16_t;
69
72 typedef detail::int32 lowp_int32_t;
73
76 typedef detail::int64 lowp_int64_t;
77
80 typedef detail::int8 lowp_i8;
81
84 typedef detail::int16 lowp_i16;
85
88 typedef detail::int32 lowp_i32;
89
92 typedef detail::int64 lowp_i64;
93
96 typedef detail::int8 mediump_int8;
97
100 typedef detail::int16 mediump_int16;
101
104 typedef detail::int32 mediump_int32;
105
108 typedef detail::int64 mediump_int64;
109
112 typedef detail::int8 mediump_int8_t;
113
116 typedef detail::int16 mediump_int16_t;
117
120 typedef detail::int32 mediump_int32_t;
121
124 typedef detail::int64 mediump_int64_t;
125
128 typedef detail::int8 mediump_i8;
129
132 typedef detail::int16 mediump_i16;
133
136 typedef detail::int32 mediump_i32;
137
140 typedef detail::int64 mediump_i64;
141
144 typedef detail::int8 highp_int8;
145
148 typedef detail::int16 highp_int16;
149
152 typedef detail::int32 highp_int32;
153
156 typedef detail::int64 highp_int64;
157
160 typedef detail::int8 highp_int8_t;
161
164 typedef detail::int16 highp_int16_t;
165
168 typedef detail::int32 highp_int32_t;
169
172 typedef detail::int64 highp_int64_t;
173
176 typedef detail::int8 highp_i8;
177
180 typedef detail::int16 highp_i16;
181
184 typedef detail::int32 highp_i32;
185
188 typedef detail::int64 highp_i64;
189
190
191 #if GLM_HAS_EXTENDED_INTEGER_TYPE
192 using std::int8_t;
193 using std::int16_t;
194 using std::int32_t;
195 using std::int64_t;
196 #else
197 typedef detail::int8 int8_t;
200
203 typedef detail::int16 int16_t;
204
207 typedef detail::int32 int32_t;
208
211 typedef detail::int64 int64_t;
212 #endif
213
216 typedef detail::int8 i8;
217
220 typedef detail::int16 i16;
221
224 typedef detail::int32 i32;
225
228 typedef detail::int64 i64;
229
230
231
234 typedef vec<1, i8, lowp> lowp_i8vec1;
235
238 typedef vec<2, i8, lowp> lowp_i8vec2;
239
242 typedef vec<3, i8, lowp> lowp_i8vec3;
243
246 typedef vec<4, i8, lowp> lowp_i8vec4;
247
248
251 typedef vec<1, i8, mediump> mediump_i8vec1;
252
255 typedef vec<2, i8, mediump> mediump_i8vec2;
256
259 typedef vec<3, i8, mediump> mediump_i8vec3;
260
263 typedef vec<4, i8, mediump> mediump_i8vec4;
264
265
268 typedef vec<1, i8, highp> highp_i8vec1;
269
272 typedef vec<2, i8, highp> highp_i8vec2;
273
276 typedef vec<3, i8, highp> highp_i8vec3;
277
280 typedef vec<4, i8, highp> highp_i8vec4;
281
282
283
286 typedef vec<1, i8, defaultp> i8vec1;
287
290 typedef vec<2, i8, defaultp> i8vec2;
291
294 typedef vec<3, i8, defaultp> i8vec3;
295
298 typedef vec<4, i8, defaultp> i8vec4;
299
300
301
302
303
306 typedef vec<1, i16, lowp> lowp_i16vec1;
307
310 typedef vec<2, i16, lowp> lowp_i16vec2;
311
314 typedef vec<3, i16, lowp> lowp_i16vec3;
315
318 typedef vec<4, i16, lowp> lowp_i16vec4;
319
320
323 typedef vec<1, i16, mediump> mediump_i16vec1;
324
327 typedef vec<2, i16, mediump> mediump_i16vec2;
328
331 typedef vec<3, i16, mediump> mediump_i16vec3;
332
335 typedef vec<4, i16, mediump> mediump_i16vec4;
336
337
340 typedef vec<1, i16, highp> highp_i16vec1;
341
344 typedef vec<2, i16, highp> highp_i16vec2;
345
348 typedef vec<3, i16, highp> highp_i16vec3;
349
352 typedef vec<4, i16, highp> highp_i16vec4;
353
354
355
356
359 typedef vec<1, i16, defaultp> i16vec1;
360
363 typedef vec<2, i16, defaultp> i16vec2;
364
367 typedef vec<3, i16, defaultp> i16vec3;
368
371 typedef vec<4, i16, defaultp> i16vec4;
372
373
374
377 typedef vec<1, i32, lowp> lowp_i32vec1;
378
381 typedef vec<2, i32, lowp> lowp_i32vec2;
382
385 typedef vec<3, i32, lowp> lowp_i32vec3;
386
389 typedef vec<4, i32, lowp> lowp_i32vec4;
390
391
394 typedef vec<1, i32, mediump> mediump_i32vec1;
395
398 typedef vec<2, i32, mediump> mediump_i32vec2;
399
402 typedef vec<3, i32, mediump> mediump_i32vec3;
403
406 typedef vec<4, i32, mediump> mediump_i32vec4;
407
408
411 typedef vec<1, i32, highp> highp_i32vec1;
412
415 typedef vec<2, i32, highp> highp_i32vec2;
416
419 typedef vec<3, i32, highp> highp_i32vec3;
420
423 typedef vec<4, i32, highp> highp_i32vec4;
424
425
428 typedef vec<1, i32, defaultp> i32vec1;
429
432 typedef vec<2, i32, defaultp> i32vec2;
433
436 typedef vec<3, i32, defaultp> i32vec3;
437
440 typedef vec<4, i32, defaultp> i32vec4;
441
442
443
444
447 typedef vec<1, i64, lowp> lowp_i64vec1;
448
451 typedef vec<2, i64, lowp> lowp_i64vec2;
452
455 typedef vec<3, i64, lowp> lowp_i64vec3;
456
459 typedef vec<4, i64, lowp> lowp_i64vec4;
460
461
464 typedef vec<1, i64, mediump> mediump_i64vec1;
465
468 typedef vec<2, i64, mediump> mediump_i64vec2;
469
472 typedef vec<3, i64, mediump> mediump_i64vec3;
473
476 typedef vec<4, i64, mediump> mediump_i64vec4;
477
478
481 typedef vec<1, i64, highp> highp_i64vec1;
482
485 typedef vec<2, i64, highp> highp_i64vec2;
486
489 typedef vec<3, i64, highp> highp_i64vec3;
490
493 typedef vec<4, i64, highp> highp_i64vec4;
494
495
498 typedef vec<1, i64, defaultp> i64vec1;
499
502 typedef vec<2, i64, defaultp> i64vec2;
503
506 typedef vec<3, i64, defaultp> i64vec3;
507
510 typedef vec<4, i64, defaultp> i64vec4;
511
512
514 // Unsigned int vector types
515
518 typedef detail::uint8 lowp_uint8;
519
522 typedef detail::uint16 lowp_uint16;
523
526 typedef detail::uint32 lowp_uint32;
527
530 typedef detail::uint64 lowp_uint64;
531
534 typedef detail::uint8 lowp_uint8_t;
535
538 typedef detail::uint16 lowp_uint16_t;
539
542 typedef detail::uint32 lowp_uint32_t;
543
546 typedef detail::uint64 lowp_uint64_t;
547
550 typedef detail::uint8 lowp_u8;
551
554 typedef detail::uint16 lowp_u16;
555
558 typedef detail::uint32 lowp_u32;
559
562 typedef detail::uint64 lowp_u64;
563
566 typedef detail::uint8 mediump_uint8;
567
570 typedef detail::uint16 mediump_uint16;
571
574 typedef detail::uint32 mediump_uint32;
575
578 typedef detail::uint64 mediump_uint64;
579
582 typedef detail::uint8 mediump_uint8_t;
583
586 typedef detail::uint16 mediump_uint16_t;
587
590 typedef detail::uint32 mediump_uint32_t;
591
594 typedef detail::uint64 mediump_uint64_t;
595
598 typedef detail::uint8 mediump_u8;
599
602 typedef detail::uint16 mediump_u16;
603
606 typedef detail::uint32 mediump_u32;
607
610 typedef detail::uint64 mediump_u64;
611
614 typedef detail::uint8 highp_uint8;
615
618 typedef detail::uint16 highp_uint16;
619
622 typedef detail::uint32 highp_uint32;
623
626 typedef detail::uint64 highp_uint64;
627
630 typedef detail::uint8 highp_uint8_t;
631
634 typedef detail::uint16 highp_uint16_t;
635
638 typedef detail::uint32 highp_uint32_t;
639
642 typedef detail::uint64 highp_uint64_t;
643
646 typedef detail::uint8 highp_u8;
647
650 typedef detail::uint16 highp_u16;
651
654 typedef detail::uint32 highp_u32;
655
658 typedef detail::uint64 highp_u64;
659
660 #if GLM_HAS_EXTENDED_INTEGER_TYPE
661 using std::uint8_t;
662 using std::uint16_t;
663 using std::uint32_t;
664 using std::uint64_t;
665 #else
666 typedef detail::uint8 uint8_t;
669
672 typedef detail::uint16 uint16_t;
673
676 typedef detail::uint32 uint32_t;
677
680 typedef detail::uint64 uint64_t;
681 #endif
682
685 typedef detail::uint8 u8;
686
689 typedef detail::uint16 u16;
690
693 typedef detail::uint32 u32;
694
697 typedef detail::uint64 u64;
698
699
700
701
702
704 // Float vector types
705
708 typedef float float32;
709
712 typedef double float64;
713
716 typedef float32 lowp_float32;
717
720 typedef float64 lowp_float64;
721
724 typedef float32 lowp_float32_t;
725
728 typedef float64 lowp_float64_t;
729
732 typedef float32 lowp_f32;
733
736 typedef float64 lowp_f64;
737
740 typedef float32 lowp_float32;
741
744 typedef float64 lowp_float64;
745
748 typedef float32 lowp_float32_t;
749
752 typedef float64 lowp_float64_t;
753
756 typedef float32 lowp_f32;
757
760 typedef float64 lowp_f64;
761
762
765 typedef float32 lowp_float32;
766
769 typedef float64 lowp_float64;
770
773 typedef float32 lowp_float32_t;
774
777 typedef float64 lowp_float64_t;
778
781 typedef float32 lowp_f32;
782
785 typedef float64 lowp_f64;
786
787
790 typedef float32 mediump_float32;
791
794 typedef float64 mediump_float64;
795
798 typedef float32 mediump_float32_t;
799
802 typedef float64 mediump_float64_t;
803
806 typedef float32 mediump_f32;
807
810 typedef float64 mediump_f64;
811
812
815 typedef float32 highp_float32;
816
819 typedef float64 highp_float64;
820
823 typedef float32 highp_float32_t;
824
827 typedef float64 highp_float64_t;
828
831 typedef float32 highp_f32;
832
835 typedef float64 highp_f64;
836
837
838 #if(defined(GLM_PRECISION_LOWP_FLOAT))
839 typedef lowp_float32_t float32_t;
842
845 typedef lowp_float64_t float64_t;
846
849 typedef lowp_f32 f32;
850
853 typedef lowp_f64 f64;
854
855 #elif(defined(GLM_PRECISION_MEDIUMP_FLOAT))
856 typedef mediump_float32 float32_t;
859
862 typedef mediump_float64 float64_t;
863
866 typedef mediump_float32 f32;
867
870 typedef mediump_float64 f64;
871
872 #else//(defined(GLM_PRECISION_HIGHP_FLOAT))
873
876 typedef highp_float32_t float32_t;
877
880 typedef highp_float64_t float64_t;
881
884 typedef highp_float32_t f32;
885
888 typedef highp_float64_t f64;
889 #endif
890
891
894 typedef vec<1, float, lowp> lowp_fvec1;
895
898 typedef vec<2, float, lowp> lowp_fvec2;
899
902 typedef vec<3, float, lowp> lowp_fvec3;
903
906 typedef vec<4, float, lowp> lowp_fvec4;
907
908
911 typedef vec<1, float, mediump> mediump_fvec1;
912
915 typedef vec<2, float, mediump> mediump_fvec2;
916
919 typedef vec<3, float, mediump> mediump_fvec3;
920
923 typedef vec<4, float, mediump> mediump_fvec4;
924
925
928 typedef vec<1, float, highp> highp_fvec1;
929
932 typedef vec<2, float, highp> highp_fvec2;
933
936 typedef vec<3, float, highp> highp_fvec3;
937
940 typedef vec<4, float, highp> highp_fvec4;
941
942
945 typedef vec<1, f32, lowp> lowp_f32vec1;
946
949 typedef vec<2, f32, lowp> lowp_f32vec2;
950
953 typedef vec<3, f32, lowp> lowp_f32vec3;
954
957 typedef vec<4, f32, lowp> lowp_f32vec4;
958
961 typedef vec<1, f32, mediump> mediump_f32vec1;
962
965 typedef vec<2, f32, mediump> mediump_f32vec2;
966
969 typedef vec<3, f32, mediump> mediump_f32vec3;
970
973 typedef vec<4, f32, mediump> mediump_f32vec4;
974
977 typedef vec<1, f32, highp> highp_f32vec1;
978
981 typedef vec<2, f32, highp> highp_f32vec2;
982
985 typedef vec<3, f32, highp> highp_f32vec3;
986
989 typedef vec<4, f32, highp> highp_f32vec4;
990
991
994 typedef vec<1, f64, lowp> lowp_f64vec1;
995
998 typedef vec<2, f64, lowp> lowp_f64vec2;
999
1002 typedef vec<3, f64, lowp> lowp_f64vec3;
1003
1006 typedef vec<4, f64, lowp> lowp_f64vec4;
1007
1010 typedef vec<1, f64, mediump> mediump_f64vec1;
1011
1014 typedef vec<2, f64, mediump> mediump_f64vec2;
1015
1018 typedef vec<3, f64, mediump> mediump_f64vec3;
1019
1022 typedef vec<4, f64, mediump> mediump_f64vec4;
1023
1026 typedef vec<1, f64, highp> highp_f64vec1;
1027
1030 typedef vec<2, f64, highp> highp_f64vec2;
1031
1034 typedef vec<3, f64, highp> highp_f64vec3;
1035
1038 typedef vec<4, f64, highp> highp_f64vec4;
1039
1040
1041
1043 // Float matrix types
1044
1047 //typedef lowp_f32 lowp_fmat1x1;
1048
1051 typedef mat<2, 2, f32, lowp> lowp_fmat2x2;
1052
1055 typedef mat<2, 3, f32, lowp> lowp_fmat2x3;
1056
1059 typedef mat<2, 4, f32, lowp> lowp_fmat2x4;
1060
1063 typedef mat<3, 2, f32, lowp> lowp_fmat3x2;
1064
1067 typedef mat<3, 3, f32, lowp> lowp_fmat3x3;
1068
1071 typedef mat<3, 4, f32, lowp> lowp_fmat3x4;
1072
1075 typedef mat<4, 2, f32, lowp> lowp_fmat4x2;
1076
1079 typedef mat<4, 3, f32, lowp> lowp_fmat4x3;
1080
1083 typedef mat<4, 4, f32, lowp> lowp_fmat4x4;
1084
1087 //typedef lowp_fmat1x1 lowp_fmat1;
1088
1091 typedef lowp_fmat2x2 lowp_fmat2;
1092
1095 typedef lowp_fmat3x3 lowp_fmat3;
1096
1099 typedef lowp_fmat4x4 lowp_fmat4;
1100
1101
1104 //typedef mediump_f32 mediump_fmat1x1;
1105
1108 typedef mat<2, 2, f32, mediump> mediump_fmat2x2;
1109
1112 typedef mat<2, 3, f32, mediump> mediump_fmat2x3;
1113
1116 typedef mat<2, 4, f32, mediump> mediump_fmat2x4;
1117
1120 typedef mat<3, 2, f32, mediump> mediump_fmat3x2;
1121
1124 typedef mat<3, 3, f32, mediump> mediump_fmat3x3;
1125
1128 typedef mat<3, 4, f32, mediump> mediump_fmat3x4;
1129
1132 typedef mat<4, 2, f32, mediump> mediump_fmat4x2;
1133
1136 typedef mat<4, 3, f32, mediump> mediump_fmat4x3;
1137
1140 typedef mat<4, 4, f32, mediump> mediump_fmat4x4;
1141
1144 //typedef mediump_fmat1x1 mediump_fmat1;
1145
1148 typedef mediump_fmat2x2 mediump_fmat2;
1149
1152 typedef mediump_fmat3x3 mediump_fmat3;
1153
1156 typedef mediump_fmat4x4 mediump_fmat4;
1157
1158
1161 //typedef highp_f32 highp_fmat1x1;
1162
1165 typedef mat<2, 2, f32, highp> highp_fmat2x2;
1166
1169 typedef mat<2, 3, f32, highp> highp_fmat2x3;
1170
1173 typedef mat<2, 4, f32, highp> highp_fmat2x4;
1174
1177 typedef mat<3, 2, f32, highp> highp_fmat3x2;
1178
1181 typedef mat<3, 3, f32, highp> highp_fmat3x3;
1182
1185 typedef mat<3, 4, f32, highp> highp_fmat3x4;
1186
1189 typedef mat<4, 2, f32, highp> highp_fmat4x2;
1190
1193 typedef mat<4, 3, f32, highp> highp_fmat4x3;
1194
1197 typedef mat<4, 4, f32, highp> highp_fmat4x4;
1198
1201 //typedef highp_fmat1x1 highp_fmat1;
1202
1205 typedef highp_fmat2x2 highp_fmat2;
1206
1209 typedef highp_fmat3x3 highp_fmat3;
1210
1213 typedef highp_fmat4x4 highp_fmat4;
1214
1215
1218 //typedef f32 lowp_f32mat1x1;
1219
1222 typedef mat<2, 2, f32, lowp> lowp_f32mat2x2;
1223
1226 typedef mat<2, 3, f32, lowp> lowp_f32mat2x3;
1227
1230 typedef mat<2, 4, f32, lowp> lowp_f32mat2x4;
1231
1234 typedef mat<3, 2, f32, lowp> lowp_f32mat3x2;
1235
1238 typedef mat<3, 3, f32, lowp> lowp_f32mat3x3;
1239
1242 typedef mat<3, 4, f32, lowp> lowp_f32mat3x4;
1243
1246 typedef mat<4, 2, f32, lowp> lowp_f32mat4x2;
1247
1250 typedef mat<4, 3, f32, lowp> lowp_f32mat4x3;
1251
1254 typedef mat<4, 4, f32, lowp> lowp_f32mat4x4;
1255
1258 //typedef detail::tmat1x1<f32, lowp> lowp_f32mat1;
1259
1262 typedef lowp_f32mat2x2 lowp_f32mat2;
1263
1266 typedef lowp_f32mat3x3 lowp_f32mat3;
1267
1270 typedef lowp_f32mat4x4 lowp_f32mat4;
1271
1272
1275 //typedef f32 mediump_f32mat1x1;
1276
1279 typedef mat<2, 2, f32, mediump> mediump_f32mat2x2;
1280
1283 typedef mat<2, 3, f32, mediump> mediump_f32mat2x3;
1284
1287 typedef mat<2, 4, f32, mediump> mediump_f32mat2x4;
1288
1291 typedef mat<3, 2, f32, mediump> mediump_f32mat3x2;
1292
1295 typedef mat<3, 3, f32, mediump> mediump_f32mat3x3;
1296
1299 typedef mat<3, 4, f32, mediump> mediump_f32mat3x4;
1300
1303 typedef mat<4, 2, f32, mediump> mediump_f32mat4x2;
1304
1307 typedef mat<4, 3, f32, mediump> mediump_f32mat4x3;
1308
1311 typedef mat<4, 4, f32, mediump> mediump_f32mat4x4;
1312
1315 //typedef detail::tmat1x1<f32, mediump> f32mat1;
1316
1319 typedef mediump_f32mat2x2 mediump_f32mat2;
1320
1323 typedef mediump_f32mat3x3 mediump_f32mat3;
1324
1327 typedef mediump_f32mat4x4 mediump_f32mat4;
1328
1329
1332 //typedef f32 highp_f32mat1x1;
1333
1336 typedef mat<2, 2, f32, highp> highp_f32mat2x2;
1337
1340 typedef mat<2, 3, f32, highp> highp_f32mat2x3;
1341
1344 typedef mat<2, 4, f32, highp> highp_f32mat2x4;
1345
1348 typedef mat<3, 2, f32, highp> highp_f32mat3x2;
1349
1352 typedef mat<3, 3, f32, highp> highp_f32mat3x3;
1353
1356 typedef mat<3, 4, f32, highp> highp_f32mat3x4;
1357
1360 typedef mat<4, 2, f32, highp> highp_f32mat4x2;
1361
1364 typedef mat<4, 3, f32, highp> highp_f32mat4x3;
1365
1368 typedef mat<4, 4, f32, highp> highp_f32mat4x4;
1369
1372 //typedef detail::tmat1x1<f32, highp> f32mat1;
1373
1376 typedef highp_f32mat2x2 highp_f32mat2;
1377
1380 typedef highp_f32mat3x3 highp_f32mat3;
1381
1384 typedef highp_f32mat4x4 highp_f32mat4;
1385
1386
1389 //typedef f64 lowp_f64mat1x1;
1390
1393 typedef mat<2, 2, f64, lowp> lowp_f64mat2x2;
1394
1397 typedef mat<2, 3, f64, lowp> lowp_f64mat2x3;
1398
1401 typedef mat<2, 4, f64, lowp> lowp_f64mat2x4;
1402
1405 typedef mat<3, 2, f64, lowp> lowp_f64mat3x2;
1406
1409 typedef mat<3, 3, f64, lowp> lowp_f64mat3x3;
1410
1413 typedef mat<3, 4, f64, lowp> lowp_f64mat3x4;
1414
1417 typedef mat<4, 2, f64, lowp> lowp_f64mat4x2;
1418
1421 typedef mat<4, 3, f64, lowp> lowp_f64mat4x3;
1422
1425 typedef mat<4, 4, f64, lowp> lowp_f64mat4x4;
1426
1429 //typedef lowp_f64mat1x1 lowp_f64mat1;
1430
1433 typedef lowp_f64mat2x2 lowp_f64mat2;
1434
1437 typedef lowp_f64mat3x3 lowp_f64mat3;
1438
1441 typedef lowp_f64mat4x4 lowp_f64mat4;
1442
1443
1446 //typedef f64 Highp_f64mat1x1;
1447
1450 typedef mat<2, 2, f64, mediump> mediump_f64mat2x2;
1451
1454 typedef mat<2, 3, f64, mediump> mediump_f64mat2x3;
1455
1458 typedef mat<2, 4, f64, mediump> mediump_f64mat2x4;
1459
1462 typedef mat<3, 2, f64, mediump> mediump_f64mat3x2;
1463
1466 typedef mat<3, 3, f64, mediump> mediump_f64mat3x3;
1467
1470 typedef mat<3, 4, f64, mediump> mediump_f64mat3x4;
1471
1474 typedef mat<4, 2, f64, mediump> mediump_f64mat4x2;
1475
1478 typedef mat<4, 3, f64, mediump> mediump_f64mat4x3;
1479
1482 typedef mat<4, 4, f64, mediump> mediump_f64mat4x4;
1483
1486 //typedef mediump_f64mat1x1 mediump_f64mat1;
1487
1490 typedef mediump_f64mat2x2 mediump_f64mat2;
1491
1494 typedef mediump_f64mat3x3 mediump_f64mat3;
1495
1498 typedef mediump_f64mat4x4 mediump_f64mat4;
1499
1502 //typedef f64 highp_f64mat1x1;
1503
1506 typedef mat<2, 2, f64, highp> highp_f64mat2x2;
1507
1510 typedef mat<2, 3, f64, highp> highp_f64mat2x3;
1511
1514 typedef mat<2, 4, f64, highp> highp_f64mat2x4;
1515
1518 typedef mat<3, 2, f64, highp> highp_f64mat3x2;
1519
1522 typedef mat<3, 3, f64, highp> highp_f64mat3x3;
1523
1526 typedef mat<3, 4, f64, highp> highp_f64mat3x4;
1527
1530 typedef mat<4, 2, f64, highp> highp_f64mat4x2;
1531
1534 typedef mat<4, 3, f64, highp> highp_f64mat4x3;
1535
1538 typedef mat<4, 4, f64, highp> highp_f64mat4x4;
1539
1542 //typedef highp_f64mat1x1 highp_f64mat1;
1543
1546 typedef highp_f64mat2x2 highp_f64mat2;
1547
1550 typedef highp_f64mat3x3 highp_f64mat3;
1551
1554 typedef highp_f64mat4x4 highp_f64mat4;
1555
1556
1557
1558
1561 typedef vec<1, u8, lowp> lowp_u8vec1;
1562
1565 typedef vec<2, u8, lowp> lowp_u8vec2;
1566
1569 typedef vec<3, u8, lowp> lowp_u8vec3;
1570
1573 typedef vec<4, u8, lowp> lowp_u8vec4;
1574
1575
1578 typedef vec<1, u8, mediump> mediump_u8vec1;
1579
1582 typedef vec<2, u8, mediump> mediump_u8vec2;
1583
1586 typedef vec<3, u8, mediump> mediump_u8vec3;
1587
1590 typedef vec<4, u8, mediump> mediump_u8vec4;
1591
1592
1595 typedef vec<1, u8, highp> highp_u8vec1;
1596
1599 typedef vec<2, u8, highp> highp_u8vec2;
1600
1603 typedef vec<3, u8, highp> highp_u8vec3;
1604
1607 typedef vec<4, u8, highp> highp_u8vec4;
1608
1609
1610
1613 typedef vec<1, u8, defaultp> u8vec1;
1614
1617 typedef vec<2, u8, defaultp> u8vec2;
1618
1621 typedef vec<3, u8, defaultp> u8vec3;
1622
1625 typedef vec<4, u8, defaultp> u8vec4;
1626
1627
1628
1629
1632 typedef vec<1, u16, lowp> lowp_u16vec1;
1633
1636 typedef vec<2, u16, lowp> lowp_u16vec2;
1637
1640 typedef vec<3, u16, lowp> lowp_u16vec3;
1641
1644 typedef vec<4, u16, lowp> lowp_u16vec4;
1645
1646
1649 typedef vec<1, u16, mediump> mediump_u16vec1;
1650
1653 typedef vec<2, u16, mediump> mediump_u16vec2;
1654
1657 typedef vec<3, u16, mediump> mediump_u16vec3;
1658
1661 typedef vec<4, u16, mediump> mediump_u16vec4;
1662
1663
1666 typedef vec<1, u16, highp> highp_u16vec1;
1667
1670 typedef vec<2, u16, highp> highp_u16vec2;
1671
1674 typedef vec<3, u16, highp> highp_u16vec3;
1675
1678 typedef vec<4, u16, highp> highp_u16vec4;
1679
1680
1681
1682
1685 typedef vec<1, u16, defaultp> u16vec1;
1686
1689 typedef vec<2, u16, defaultp> u16vec2;
1690
1693 typedef vec<3, u16, defaultp> u16vec3;
1694
1697 typedef vec<4, u16, defaultp> u16vec4;
1698
1699
1700
1703 typedef vec<1, u32, lowp> lowp_u32vec1;
1704
1707 typedef vec<2, u32, lowp> lowp_u32vec2;
1708
1711 typedef vec<3, u32, lowp> lowp_u32vec3;
1712
1715 typedef vec<4, u32, lowp> lowp_u32vec4;
1716
1717
1720 typedef vec<1, u32, mediump> mediump_u32vec1;
1721
1724 typedef vec<2, u32, mediump> mediump_u32vec2;
1725
1728 typedef vec<3, u32, mediump> mediump_u32vec3;
1729
1732 typedef vec<4, u32, mediump> mediump_u32vec4;
1733
1734
1737 typedef vec<1, u32, highp> highp_u32vec1;
1738
1741 typedef vec<2, u32, highp> highp_u32vec2;
1742
1745 typedef vec<3, u32, highp> highp_u32vec3;
1746
1749 typedef vec<4, u32, highp> highp_u32vec4;
1750
1751
1752
1755 typedef vec<1, u32, defaultp> u32vec1;
1756
1759 typedef vec<2, u32, defaultp> u32vec2;
1760
1763 typedef vec<3, u32, defaultp> u32vec3;
1764
1767 typedef vec<4, u32, defaultp> u32vec4;
1768
1769
1770
1771
1774 typedef vec<1, u64, lowp> lowp_u64vec1;
1775
1778 typedef vec<2, u64, lowp> lowp_u64vec2;
1779
1782 typedef vec<3, u64, lowp> lowp_u64vec3;
1783
1786 typedef vec<4, u64, lowp> lowp_u64vec4;
1787
1788
1791 typedef vec<1, u64, mediump> mediump_u64vec1;
1792
1795 typedef vec<2, u64, mediump> mediump_u64vec2;
1796
1799 typedef vec<3, u64, mediump> mediump_u64vec3;
1800
1803 typedef vec<4, u64, mediump> mediump_u64vec4;
1804
1805
1808 typedef vec<1, u64, highp> highp_u64vec1;
1809
1812 typedef vec<2, u64, highp> highp_u64vec2;
1813
1816 typedef vec<3, u64, highp> highp_u64vec3;
1817
1820 typedef vec<4, u64, highp> highp_u64vec4;
1821
1822
1823
1824
1827 typedef vec<1, u64, defaultp> u64vec1;
1828
1831 typedef vec<2, u64, defaultp> u64vec2;
1832
1835 typedef vec<3, u64, defaultp> u64vec3;
1836
1839 typedef vec<4, u64, defaultp> u64vec4;
1840
1841
1843 // Float vector types
1844
1847 typedef float32 float32_t;
1848
1851 typedef float32 f32;
1852
1853 # ifndef GLM_FORCE_SINGLE_ONLY
1854
1857 typedef float64 float64_t;
1858
1861 typedef float64 f64;
1862 # endif//GLM_FORCE_SINGLE_ONLY
1863
1866 typedef vec<1, float, defaultp> fvec1;
1867
1870 typedef vec<2, float, defaultp> fvec2;
1871
1874 typedef vec<3, float, defaultp> fvec3;
1875
1878 typedef vec<4, float, defaultp> fvec4;
1879
1880
1883 typedef vec<1, f32, defaultp> f32vec1;
1884
1887 typedef vec<2, f32, defaultp> f32vec2;
1888
1891 typedef vec<3, f32, defaultp> f32vec3;
1892
1895 typedef vec<4, f32, defaultp> f32vec4;
1896
1897 # ifndef GLM_FORCE_SINGLE_ONLY
1898 typedef vec<1, f64, defaultp> f64vec1;
1901
1904 typedef vec<2, f64, defaultp> f64vec2;
1905
1908 typedef vec<3, f64, defaultp> f64vec3;
1909
1912 typedef vec<4, f64, defaultp> f64vec4;
1913 # endif//GLM_FORCE_SINGLE_ONLY
1914
1915
1917 // Float matrix types
1918
1921 //typedef detail::tmat1x1<f32> fmat1;
1922
1925 typedef mat<2, 2, f32, defaultp> fmat2;
1926
1929 typedef mat<3, 3, f32, defaultp> fmat3;
1930
1933 typedef mat<4, 4, f32, defaultp> fmat4;
1934
1935
1938 //typedef f32 fmat1x1;
1939
1942 typedef mat<2, 2, f32, defaultp> fmat2x2;
1943
1946 typedef mat<2, 3, f32, defaultp> fmat2x3;
1947
1950 typedef mat<2, 4, f32, defaultp> fmat2x4;
1951
1954 typedef mat<3, 2, f32, defaultp> fmat3x2;
1955
1958 typedef mat<3, 3, f32, defaultp> fmat3x3;
1959
1962 typedef mat<3, 4, f32, defaultp> fmat3x4;
1963
1966 typedef mat<4, 2, f32, defaultp> fmat4x2;
1967
1970 typedef mat<4, 3, f32, defaultp> fmat4x3;
1971
1974 typedef mat<4, 4, f32, defaultp> fmat4x4;
1975
1976
1979 //typedef detail::tmat1x1<f32, defaultp> f32mat1;
1980
1983 typedef mat<2, 2, f32, defaultp> f32mat2;
1984
1987 typedef mat<3, 3, f32, defaultp> f32mat3;
1988
1991 typedef mat<4, 4, f32, defaultp> f32mat4;
1992
1993
1996 //typedef f32 f32mat1x1;
1997
2000 typedef mat<2, 2, f32, defaultp> f32mat2x2;
2001
2004 typedef mat<2, 3, f32, defaultp> f32mat2x3;
2005
2008 typedef mat<2, 4, f32, defaultp> f32mat2x4;
2009
2012 typedef mat<3, 2, f32, defaultp> f32mat3x2;
2013
2016 typedef mat<3, 3, f32, defaultp> f32mat3x3;
2017
2020 typedef mat<3, 4, f32, defaultp> f32mat3x4;
2021
2024 typedef mat<4, 2, f32, defaultp> f32mat4x2;
2025
2028 typedef mat<4, 3, f32, defaultp> f32mat4x3;
2029
2032 typedef mat<4, 4, f32, defaultp> f32mat4x4;
2033
2034
2035 # ifndef GLM_FORCE_SINGLE_ONLY
2036
2039 //typedef detail::tmat1x1<f64, defaultp> f64mat1;
2040
2043 typedef mat<2, 2, f64, defaultp> f64mat2;
2044
2047 typedef mat<3, 3, f64, defaultp> f64mat3;
2048
2051 typedef mat<4, 4, f64, defaultp> f64mat4;
2052
2053
2056 //typedef f64 f64mat1x1;
2057
2060 typedef mat<2, 2, f64, defaultp> f64mat2x2;
2061
2064 typedef mat<2, 3, f64, defaultp> f64mat2x3;
2065
2068 typedef mat<2, 4, f64, defaultp> f64mat2x4;
2069
2072 typedef mat<3, 2, f64, defaultp> f64mat3x2;
2073
2076 typedef mat<3, 3, f64, defaultp> f64mat3x3;
2077
2080 typedef mat<3, 4, f64, defaultp> f64mat3x4;
2081
2084 typedef mat<4, 2, f64, defaultp> f64mat4x2;
2085
2088 typedef mat<4, 3, f64, defaultp> f64mat4x3;
2089
2092 typedef mat<4, 4, f64, defaultp> f64mat4x4;
2093
2094 # endif//GLM_FORCE_SINGLE_ONLY
2095
2097 // Quaternion types
2098
2101 typedef qua<f32, defaultp> f32quat;
2102
2105 typedef qua<f32, lowp> lowp_f32quat;
2106
2109 typedef qua<f64, lowp> lowp_f64quat;
2110
2113 typedef qua<f32, mediump> mediump_f32quat;
2114
2115 # ifndef GLM_FORCE_SINGLE_ONLY
2116
2119 typedef qua<f64, mediump> mediump_f64quat;
2120
2123 typedef qua<f32, highp> highp_f32quat;
2124
2127 typedef qua<f64, highp> highp_f64quat;
2128
2131 typedef qua<f64, defaultp> f64quat;
2132
2133 # endif//GLM_FORCE_SINGLE_ONLY
2134
2136 }//namespace glm
2137
2138 #include "type_precision.inl"
glm::highp_u16vec1
vec< 1, u16, highp > highp_u16vec1
High qualifier 16 bit unsigned integer scalar type.
Definition: fwd.hpp:354
glm::highp_f32mat4x2
mat< 4, 2, f32, highp > highp_f32mat4x2
High single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:696
glm::highp_u64
uint64 highp_u64
High qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:133
glm::mediump_f64vec1
vec< 1, f64, mediump > mediump_f64vec1
Medium double-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:491
glm::f32vec3
vec< 3, f32, defaultp > f32vec3
Single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:463
glm::mediump_fmat2
mat< 2, 2, f32, mediump > mediump_fmat2
Medium single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:528
glm::highp_float64_t
double highp_float64_t
High 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:175
glm::f64mat4
mat< 4, 4, f64, defaultp > f64mat4
Double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:586
glm::f64mat2
mat< 2, 2, f64, defaultp > f64mat2
Double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:584
glm::mediump_fmat4x3
mat< 4, 3, f32, mediump > mediump_fmat4x3
Medium single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:647
glm::mediump_f32mat3
mat< 3, 3, f32, mediump > mediump_f32mat3
Medium single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:545
glm::mediump_uint32_t
uint32 mediump_uint32_t
Medium qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:127
glm::lowp_uint64
uint64 lowp_uint64
Low qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:136
glm::mediump_fmat2x2
mat< 2, 2, f32, mediump > mediump_fmat2x2
Medium single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:640
glm::f32vec1
vec< 1, f32, defaultp > f32vec1
Single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:461
glm::highp_f32mat4
mat< 4, 4, f32, highp > highp_f32mat4
High single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:550
glm::highp_float64
double highp_float64
High 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:170
glm::lowp_u8
uint8 lowp_u8
Low qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:89
glm::u32
uint32 u32
Default qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:120
glm::f64mat3
mat< 3, 3, f64, defaultp > f64mat3
Double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:585
glm::lowp_float64
double lowp_float64
Low 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:168
glm::i32vec1
vec< 1, i32, defaultp > i32vec1
32 bit signed integer scalar type.
Definition: fwd.hpp:277
glm::highp_uint16
uint16 highp_uint16
High qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:110
glm::mediump_f64mat2x4
mat< 2, 4, f64, mediump > mediump_f64mat2x4
Medium double-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:762
glm::highp_i64vec4
vec< 4, i64, highp > highp_i64vec4
High qualifier 64 bit signed integer vector of 4 components type.
Definition: fwd.hpp:295
glm::f64mat3x4
mat< 3, 4, f64, defaultp > f64mat3x4
Double-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:787
glm::fmat2
mat< 2, 2, f32, defaultp > fmat2
Single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:536
glm::i16vec3
vec< 3, i16, defaultp > i16vec3
16 bit signed integer vector of 3 components type.
Definition: fwd.hpp:259
glm::lowp_uint32_t
uint32 lowp_uint32_t
Low qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:126
glm::lowp_fvec2
vec< 2, float, lowp > lowp_fvec2
Low single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:427
glm::mediump_uint32
uint32 mediump_uint32
Medium qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:123
glm::mediump_fmat4
mat< 4, 4, f32, mediump > mediump_fmat4
Medium single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:530
glm::highp_uint64
uint64 highp_uint64
High qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:138
glm::lowp_fmat2
mat< 2, 2, f32, lowp > lowp_fmat2
Low single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:524
glm::lowp_uint32
uint32 lowp_uint32
Low qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:122
glm::lowp_fvec3
vec< 3, float, lowp > lowp_fvec3
Low single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:428
glm::mediump_fvec2
vec< 2, float, mediump > mediump_fvec2
Medium Single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:432
glm::lowp_fmat3x4
mat< 3, 4, f32, lowp > lowp_fmat3x4
Low single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:635
glm::lowp_f64mat2x2
mat< 2, 2, f64, lowp > lowp_f64mat2x2
Low double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:750
glm::i64vec4
vec< 4, i64, defaultp > i64vec4
64 bit signed integer vector of 4 components type.
Definition: fwd.hpp:300
glm::u16vec3
vec< 3, u16, defaultp > u16vec3
Default qualifier 16 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:361
glm::lowp_u64vec1
vec< 1, u64, lowp > lowp_u64vec1
Low qualifier 64 bit unsigned integer scalar type.
Definition: fwd.hpp:384
glm::mediump_u16vec1
vec< 1, u16, mediump > mediump_u16vec1
Medium qualifier 16 bit unsigned integer scalar type.
Definition: fwd.hpp:349
glm::i8vec2
vec< 2, i8, defaultp > i8vec2
8 bit signed integer vector of 2 components type.
Definition: fwd.hpp:238
glm::mediump_f64mat2x3
mat< 2, 3, f64, mediump > mediump_f64mat2x3
Medium double-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:761
glm::lowp_u32vec4
vec< 4, u32, lowp > lowp_u32vec4
Low qualifier 32 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:367
glm::highp_f32vec4
vec< 4, f32, highp > highp_f32vec4
High single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:459
glm::lowp_f32vec1
vec< 1, f32, lowp > lowp_f32vec1
Low single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:446
glm::highp_f32mat2x3
mat< 2, 3, f32, highp > highp_f32mat2x3
High single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:691
glm::highp_int64
int64 highp_int64
High qualifier 64 bit signed integer type.
Definition: fwd.hpp:80
glm::mediump_i32vec2
vec< 2, i32, mediump > mediump_i32vec2
Medium qualifier 32 bit signed integer vector of 2 components type.
Definition: fwd.hpp:268
glm::lowp_f64mat4
mat< 4, 4, f64, lowp > lowp_f64mat4
Low double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:574
glm::fmat4
mat< 4, 4, f32, defaultp > fmat4
Single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:538
glm::mediump_fmat3x4
mat< 3, 4, f32, mediump > mediump_fmat3x4
Medium single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:645
glm::lowp_int16_t
int16 lowp_int16_t
Low qualifier 16 bit signed integer type.
Definition: fwd.hpp:54
glm::highp_i32vec4
vec< 4, i32, highp > highp_i32vec4
High qualifier 32 bit signed integer vector of 4 components type.
Definition: fwd.hpp:275
glm::f32mat4x2
mat< 4, 2, f32, defaultp > f32mat4x2
Single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:702
glm::highp_fmat3x2
mat< 3, 2, f32, highp > highp_fmat3x2
High single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:653
glm::mediump_fmat2x3
mat< 2, 3, f32, mediump > mediump_fmat2x3
Medium single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:641
glm::mediump_u32
uint32 mediump_u32
Medium qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:118
glm::lowp_fmat3x2
mat< 3, 2, f32, lowp > lowp_fmat3x2
Low single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:633
glm::mediump_f64mat4x2
mat< 4, 2, f64, mediump > mediump_f64mat4x2
Medium double-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:766
glm::highp_u16vec2
vec< 2, u16, highp > highp_u16vec2
High qualifier 16 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:355
glm::highp_f64vec1
vec< 1, f64, highp > highp_f64vec1
High double-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:496
glm::mediump_i16vec2
vec< 2, i16, mediump > mediump_i16vec2
Medium qualifier 16 bit signed integer vector of 2 components type.
Definition: fwd.hpp:248
glm::highp_fmat2x4
mat< 2, 4, f32, highp > highp_fmat2x4
High single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:652
glm::u64vec3
vec< 3, u64, defaultp > u64vec3
Default qualifier 64 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:401
glm::lowp_uint8
uint8 lowp_uint8
Low qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:94
glm::lowp_f32mat3x2
mat< 3, 2, f32, lowp > lowp_f32mat3x2
Low single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:673
glm::lowp_u64
uint64 lowp_u64
Low qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:131
glm::highp_i64vec3
vec< 3, i64, highp > highp_i64vec3
High qualifier 64 bit signed integer vector of 3 components type.
Definition: fwd.hpp:294
glm::mediump_int8
int8 mediump_int8
Medium qualifier 8 bit signed integer type.
Definition: fwd.hpp:37
glm::lowp_int64
int64 lowp_int64
Low qualifier 64 bit signed integer type.
Definition: fwd.hpp:78
glm::mediump_f32mat4x2
mat< 4, 2, f32, mediump > mediump_f32mat4x2
Medium single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:686
glm::lowp_f64vec3
vec< 3, f64, lowp > lowp_f64vec3
Low double-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:488
glm::u64vec2
vec< 2, u64, defaultp > u64vec2
Default qualifier 64 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:400
glm::lowp_i64vec3
vec< 3, i64, lowp > lowp_i64vec3
Low qualifier 64 bit signed integer vector of 3 components type.
Definition: fwd.hpp:284
glm::mediump_i8vec2
vec< 2, i8, mediump > mediump_i8vec2
Medium qualifier 8 bit signed integer vector of 2 components type.
Definition: fwd.hpp:228
glm::f32mat3x4
mat< 3, 4, f32, defaultp > f32mat3x4
Single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:707
glm::highp_i16vec3
vec< 3, i16, highp > highp_i16vec3
High qualifier 16 bit signed integer vector of 3 components type.
Definition: fwd.hpp:254
glm::mediump_i16vec3
vec< 3, i16, mediump > mediump_i16vec3
Medium qualifier 16 bit signed integer vector of 3 components type.
Definition: fwd.hpp:249
glm::u64
uint64 u64
Default qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:134
glm::f64vec1
vec< 1, f64, defaultp > f64vec1
Double-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:501
glm::mediump_fmat3x2
mat< 3, 2, f32, mediump > mediump_fmat3x2
Medium single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:643
glm::mediump_i64vec1
vec< 1, i64, mediump > mediump_i64vec1
Medium qualifier 64 bit signed integer scalar type.
Definition: fwd.hpp:287
glm::i16vec1
vec< 1, i16, defaultp > i16vec1
16 bit signed integer scalar type.
Definition: fwd.hpp:257
glm::lowp_f64mat3x3
mat< 3, 3, f64, lowp > lowp_f64mat3x3
Low double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:754
glm::lowp_f64vec2
vec< 2, f64, lowp > lowp_f64vec2
Low double-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:487
glm::highp_fmat2x3
mat< 2, 3, f32, highp > highp_fmat2x3
High single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:651
glm::lowp_f64mat3
mat< 3, 3, f64, lowp > lowp_f64mat3
Low double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:573
glm::lowp_f32mat4x3
mat< 4, 3, f32, lowp > lowp_f32mat4x3
Low single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:677
glm::mediump_u64vec3
vec< 3, u64, mediump > mediump_u64vec3
Medium qualifier 64 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:391
glm::mediump_float64
double mediump_float64
Medium 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:169
glm::float64
double float64
Double-qualifier floating-point scalar.
Definition: fwd.hpp:171
glm::highp_i16vec2
vec< 2, i16, highp > highp_i16vec2
High qualifier 16 bit signed integer vector of 2 components type.
Definition: fwd.hpp:253
glm::fmat4x2
mat< 4, 2, f32, defaultp > fmat4x2
Single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:662
glm::lowp_f64mat2x3
mat< 2, 3, f64, lowp > lowp_f64mat2x3
Low double-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:751
glm::fmat3x4
mat< 3, 4, f32, defaultp > fmat3x4
Single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:667
glm::lowp_u32vec3
vec< 3, u32, lowp > lowp_u32vec3
Low qualifier 32 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:366
glm::f32mat2x4
mat< 2, 4, f32, defaultp > f32mat2x4
Single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:706
glm::lowp_fvec4
vec< 4, float, lowp > lowp_fvec4
Low single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:429
glm::mediump_f32vec4
vec< 4, f32, mediump > mediump_f32vec4
Medium single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:454
glm::i16vec4
vec< 4, i16, defaultp > i16vec4
16 bit signed integer vector of 4 components type.
Definition: fwd.hpp:260
glm::lowp_uint8_t
uint8 lowp_uint8_t
Low qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:98
glm::highp_uint32_t
uint32 highp_uint32_t
High qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:128
glm::fmat3x3
mat< 3, 3, f32, defaultp > fmat3x3
Single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:664
glm::mediump_f64mat3x4
mat< 3, 4, f64, mediump > mediump_f64mat3x4
Medium double-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:765
glm::lowp_fmat2x3
mat< 2, 3, f32, lowp > lowp_fmat2x3
Low single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:631
glm::lowp_u32vec1
vec< 1, u32, lowp > lowp_u32vec1
Low qualifier 32 bit unsigned integer scalar type.
Definition: fwd.hpp:364
glm::f32mat2x3
mat< 2, 3, f32, defaultp > f32mat2x3
Single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:703
glm::mediump_i32vec1
vec< 1, i32, mediump > mediump_i32vec1
Medium qualifier 32 bit signed integer scalar type.
Definition: fwd.hpp:267
glm::highp_u16vec4
vec< 4, u16, highp > highp_u16vec4
High qualifier 16 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:357
glm::lowp_i32vec1
vec< 1, i32, lowp > lowp_i32vec1
Low qualifier 32 bit signed integer scalar type.
Definition: fwd.hpp:262
glm::lowp_i64vec1
vec< 1, i64, lowp > lowp_i64vec1
Low qualifier 64 bit signed integer scalar type.
Definition: fwd.hpp:282
glm::highp_u32vec1
vec< 1, u32, highp > highp_u32vec1
High qualifier 32 bit unsigned integer scalar type.
Definition: fwd.hpp:374
glm::mediump_int16
int16 mediump_int16
Medium qualifier 16 bit signed integer type.
Definition: fwd.hpp:51
glm::mediump_u16
uint16 mediump_u16
Medium qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:104
glm::f64quat
qua< f64, defaultp > f64quat
Double-qualifier floating-point quaternion.
Definition: fwd.hpp:815
glm::mediump_f64vec3
vec< 3, f64, mediump > mediump_f64vec3
Medium double-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:493
glm::u64vec1
vec< 1, u64, defaultp > u64vec1
Default qualifier 64 bit unsigned integer scalar type.
Definition: fwd.hpp:399
glm::int64_t
int64 int64_t
64 bit signed integer type.
Definition: fwd.hpp:85
glm::u8vec1
vec< 1, u8, defaultp > u8vec1
Default qualifier 8 bit unsigned integer scalar type.
Definition: fwd.hpp:339
glm::highp_i8vec1
vec< 1, i8, highp > highp_i8vec1
High qualifier 8 bit signed integer scalar type.
Definition: fwd.hpp:232
glm::u8vec4
vec< 4, u8, defaultp > u8vec4
Default qualifier 8 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:342
glm::int8_t
int8 int8_t
8 bit signed integer type.
Definition: fwd.hpp:43
glm::i32
int32 i32
32 bit signed integer type.
Definition: fwd.hpp:62
glm::mediump_u32vec1
vec< 1, u32, mediump > mediump_u32vec1
Medium qualifier 32 bit unsigned integer scalar type.
Definition: fwd.hpp:369
glm::f64mat2x2
mat< 2, 2, f64, defaultp > f64mat2x2
Double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:780
glm::lowp_f32mat2x2
mat< 2, 2, f32, lowp > lowp_f32mat2x2
Low single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:670
glm::lowp_f32vec4
vec< 4, f32, lowp > lowp_f32vec4
Low single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:449
glm::highp_fvec3
vec< 3, float, highp > highp_fvec3
High Single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:438
glm::lowp_f64mat4x2
mat< 4, 2, f64, lowp > lowp_f64mat4x2
Low double-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:756
glm::mediump_fmat3x3
mat< 3, 3, f32, mediump > mediump_fmat3x3
Medium single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:644
glm::highp_i64vec1
vec< 1, i64, highp > highp_i64vec1
High qualifier 64 bit signed integer scalar type.
Definition: fwd.hpp:292
glm::i8vec4
vec< 4, i8, defaultp > i8vec4
8 bit signed integer vector of 4 components type.
Definition: fwd.hpp:240
glm::highp_int32
int32 highp_int32
High qualifier 32 bit signed integer type.
Definition: fwd.hpp:66
glm::mediump_f32mat2x3
mat< 2, 3, f32, mediump > mediump_f32mat2x3
Medium single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:681
glm::lowp_f64mat3x2
mat< 3, 2, f64, lowp > lowp_f64mat3x2
Low double-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:753
glm::highp_u32
uint32 highp_u32
High qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:119
glm::highp_i32
int32 highp_i32
High qualifier 32 bit signed integer type.
Definition: fwd.hpp:61
glm::u64vec4
vec< 4, u64, defaultp > u64vec4
Default qualifier 64 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:402
glm::f32vec4
vec< 4, f32, defaultp > f32vec4
Single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:464
glm::f64mat2x3
mat< 2, 3, f64, defaultp > f64mat2x3
Double-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:783
glm::mediump_f64mat4x4
mat< 4, 4, f64, mediump > mediump_f64mat4x4
Medium double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:768
glm::lowp_u16vec4
vec< 4, u16, lowp > lowp_u16vec4
Low qualifier 16 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:347
glm::highp_uint32
uint32 highp_uint32
High qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:124
glm::lowp_f32mat4
mat< 4, 4, f32, lowp > lowp_f32mat4
Low single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:542
glm::f64mat3x2
mat< 3, 2, f64, defaultp > f64mat3x2
Double-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:781
glm::mediump_float32
float mediump_float32
Medium 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:153
glm::u32vec1
vec< 1, u32, defaultp > u32vec1
Default qualifier 32 bit unsigned integer scalar type.
Definition: fwd.hpp:379
glm::mediump_f64vec4
vec< 4, f64, mediump > mediump_f64vec4
Medium double-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:494
glm::f64mat3x3
mat< 3, 3, f64, defaultp > f64mat3x3
Double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:784
glm::highp_float32
float highp_float32
High 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:154
glm::highp_uint8
uint8 highp_uint8
High qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:96
glm::highp_i8
int8 highp_i8
High qualifier 8 bit signed integer type.
Definition: fwd.hpp:33
glm::lowp_f64mat2x4
mat< 2, 4, f64, lowp > lowp_f64mat2x4
Low double-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:752
glm::lowp_f64mat3x4
mat< 3, 4, f64, lowp > lowp_f64mat3x4
Low double-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:755
glm::mediump_i8
int8 mediump_i8
Medium qualifier 8 bit signed integer type.
Definition: fwd.hpp:32
glm::highp_int64_t
int64 highp_int64_t
High qualifier 64 bit signed integer type.
Definition: fwd.hpp:84
glm::f32mat4x4
mat< 4, 4, f32, defaultp > f32mat4x4
Single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:708
glm::float32_t
float float32_t
Default 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:160
glm::f32mat2x2
mat< 2, 2, f32, defaultp > f32mat2x2
Single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:700
glm::lowp_i64vec2
vec< 2, i64, lowp > lowp_i64vec2
Low qualifier 64 bit signed integer vector of 2 components type.
Definition: fwd.hpp:283
glm::lowp_f32mat2x4
mat< 2, 4, f32, lowp > lowp_f32mat2x4
Low single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:672
glm::uint32_t
uint32 uint32_t
Default qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:129
glm::highp_f32mat3
mat< 3, 3, f32, highp > highp_f32mat3
High single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:549
glm::mediump_f64mat3x3
mat< 3, 3, f64, mediump > mediump_f64mat3x3
Medium double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:764
glm::u8
uint8 u8
Default qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:92
glm::highp_i32vec3
vec< 3, i32, highp > highp_i32vec3
High qualifier 32 bit signed integer vector of 3 components type.
Definition: fwd.hpp:274
glm::float32
float float32
Single-qualifier floating-point scalar.
Definition: fwd.hpp:155
glm::fvec4
vec< 4, f32, defaultp > fvec4
Single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:444
glm::highp_i32vec1
vec< 1, i32, highp > highp_i32vec1
High qualifier 32 bit signed integer scalar type.
Definition: fwd.hpp:272
glm::lowp_f32mat3
mat< 3, 3, f32, lowp > lowp_f32mat3
Low single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:541
glm::u16vec1
vec< 1, u16, defaultp > u16vec1
Default qualifier 16 bit unsigned integer scalar type.
Definition: fwd.hpp:359
glm::i8vec1
vec< 1, i8, defaultp > i8vec1
8 bit signed integer scalar type.
Definition: fwd.hpp:237
glm::mediump_i32vec3
vec< 3, i32, mediump > mediump_i32vec3
Medium qualifier 32 bit signed integer vector of 3 components type.
Definition: fwd.hpp:269
glm::i32vec2
vec< 2, i32, defaultp > i32vec2
32 bit signed integer vector of 2 components type.
Definition: fwd.hpp:278
glm::lowp_i16vec2
vec< 2, i16, lowp > lowp_i16vec2
Low qualifier 16 bit signed integer vector of 2 components type.
Definition: fwd.hpp:243
glm::mediump_u64vec2
vec< 2, u64, mediump > mediump_u64vec2
Medium qualifier 64 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:390
glm::lowp_u8vec4
vec< 4, u8, lowp > lowp_u8vec4
Low qualifier 8 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:327
glm::highp_f32mat3x3
mat< 3, 3, f32, highp > highp_f32mat3x3
High single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:694
glm::highp_u8vec1
vec< 1, u8, highp > highp_u8vec1
High qualifier 8 bit unsigned integer scalar type.
Definition: fwd.hpp:334
glm::highp_uint8_t
uint8 highp_uint8_t
High qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:100
glm::mediump_u32vec4
vec< 4, u32, mediump > mediump_u32vec4
Medium qualifier 32 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:372
glm::highp_f32mat2x2
mat< 2, 2, f32, highp > highp_f32mat2x2
High single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:690
glm::highp_f64vec4
vec< 4, f64, highp > highp_f64vec4
High double-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:499
glm::lowp_u8vec3
vec< 3, u8, lowp > lowp_u8vec3
Low qualifier 8 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:326
glm::highp_f32
float highp_f32
High 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:149
glm::mediump_uint64
uint64 mediump_uint64
Medium qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:137
glm::highp_int32_t
int32 highp_int32_t
32 bit signed integer type.
Definition: fwd.hpp:70
glm::f64vec3
vec< 3, f64, defaultp > f64vec3
Double-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:503
glm::lowp_f32mat2x3
mat< 2, 3, f32, lowp > lowp_f32mat2x3
Low single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:671
glm::mediump_u16vec3
vec< 3, u16, mediump > mediump_u16vec3
Medium qualifier 16 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:351
glm::f64mat2x4
mat< 2, 4, f64, defaultp > f64mat2x4
Double-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:786
glm::f32mat3
mat< 3, 3, f32, defaultp > f32mat3
Single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:553
glm::mediump_f64mat2x2
mat< 2, 2, f64, mediump > mediump_f64mat2x2
Medium double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:760
glm::mediump_u64
uint64 mediump_u64
Medium qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:132
glm::highp_i16vec4
vec< 4, i16, highp > highp_i16vec4
High qualifier 16 bit signed integer vector of 4 components type.
Definition: fwd.hpp:255
glm::lowp_fmat4
mat< 4, 4, f32, lowp > lowp_fmat4
Low single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:526
glm::mediump_u32vec2
vec< 2, u32, mediump > mediump_u32vec2
Medium qualifier 32 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:370
glm::highp_u64vec3
vec< 3, u64, highp > highp_u64vec3
High qualifier 64 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:396
glm::lowp_u16
uint16 lowp_u16
Low qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:103
glm::lowp_i16vec3
vec< 3, i16, lowp > lowp_i16vec3
Low qualifier 16 bit signed integer vector of 3 components type.
Definition: fwd.hpp:244
glm::lowp_u16vec3
vec< 3, u16, lowp > lowp_u16vec3
Low qualifier 16 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:346
glm::lowp_f32vec3
vec< 3, f32, lowp > lowp_f32vec3
Low single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:448
glm::highp_fmat4
mat< 4, 4, f32, highp > highp_fmat4
High single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:534
glm::lowp_fmat3
mat< 3, 3, f32, lowp > lowp_fmat3
Low single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:525
glm::highp_i16
int16 highp_i16
High qualifier 16 bit signed integer type.
Definition: fwd.hpp:47
glm::mediump_f32quat
qua< f32, mediump > mediump_f32quat
Medium single-qualifier floating-point quaternion.
Definition: fwd.hpp:803
glm::highp_int8
int8 highp_int8
High qualifier 8 bit signed integer type.
Definition: fwd.hpp:38
glm::f64mat4x4
mat< 4, 4, f64, defaultp > f64mat4x4
Double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:788
glm::fmat4x3
mat< 4, 3, f32, defaultp > fmat4x3
Single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:665
glm::lowp_fmat2x4
mat< 2, 4, f32, lowp > lowp_fmat2x4
Low single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:632
glm::highp_f64mat3
mat< 3, 3, f64, highp > highp_f64mat3
High double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:581
glm::mediump_i8vec3
vec< 3, i8, mediump > mediump_i8vec3
Medium qualifier 8 bit signed integer vector of 3 components type.
Definition: fwd.hpp:229
glm::highp_f32vec1
vec< 1, f32, highp > highp_f32vec1
High single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:456
glm::lowp_i8vec3
vec< 3, i8, lowp > lowp_i8vec3
Low qualifier 8 bit signed integer vector of 3 components type.
Definition: fwd.hpp:224
glm::lowp_f64mat4x3
mat< 4, 3, f64, lowp > lowp_f64mat4x3
Low double-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:757
glm::highp_u64vec4
vec< 4, u64, highp > highp_u64vec4
High qualifier 64 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:397
glm::fvec3
vec< 3, f32, defaultp > fvec3
Single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:443
glm::i16vec2
vec< 2, i16, defaultp > i16vec2
16 bit signed integer vector of 2 components type.
Definition: fwd.hpp:258
glm::f32mat4x3
mat< 4, 3, f32, defaultp > f32mat4x3
Single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:705
glm::f32mat2
mat< 2, 2, f32, defaultp > f32mat2
Single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:552
glm::mediump_u16vec2
vec< 2, u16, mediump > mediump_u16vec2
Medium qualifier 16 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:350
glm::mediump_fmat2x4
mat< 2, 4, f32, mediump > mediump_fmat2x4
Medium single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:642
glm::lowp_f32mat4x4
mat< 4, 4, f32, lowp > lowp_f32mat4x4
Low single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:678
glm::lowp_u8vec2
vec< 2, u8, lowp > lowp_u8vec2
Low qualifier 8 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:325
glm::mediump_f64mat3
mat< 3, 3, f64, mediump > mediump_f64mat3
Medium double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:577
glm::lowp_i16
int16 lowp_i16
Low qualifier 16 bit signed integer type.
Definition: fwd.hpp:45
glm::highp_fmat3x4
mat< 3, 4, f32, highp > highp_fmat3x4
High single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:655
glm::float64_t
double float64_t
Default 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:176
glm::highp_f64mat4x4
mat< 4, 4, f64, highp > highp_f64mat4x4
High double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:778
glm::mediump_f32mat4x3
mat< 4, 3, f32, mediump > mediump_f32mat4x3
Medium single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:687
glm::lowp_int16
int16 lowp_int16
Low qualifier 16 bit signed integer type.
Definition: fwd.hpp:50
glm::mediump_fmat3
mat< 3, 3, f32, mediump > mediump_fmat3
Medium single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:529
glm::highp_f32mat4x4
mat< 4, 4, f32, highp > highp_f32mat4x4
High single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:698
glm::lowp_int64_t
int64 lowp_int64_t
Low qualifier 64 bit signed integer type.
Definition: fwd.hpp:82
glm::uint16_t
uint16 uint16_t
Default qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:115
glm::highp_f64vec2
vec< 2, f64, highp > highp_f64vec2
High double-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:497
glm::lowp_u64vec2
vec< 2, u64, lowp > lowp_u64vec2
Low qualifier 64 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:385
glm::fmat3
mat< 3, 3, f32, defaultp > fmat3
Single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:537
glm::mediump_f32mat3x2
mat< 3, 2, f32, mediump > mediump_f32mat3x2
Medium single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:683
glm::lowp_f32mat4x2
mat< 4, 2, f32, lowp > lowp_f32mat4x2
Low single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:676
glm::lowp_int32
int32 lowp_int32
Low qualifier 32 bit signed integer type.
Definition: fwd.hpp:64
glm::mediump_i64vec4
vec< 4, i64, mediump > mediump_i64vec4
Medium qualifier 64 bit signed integer vector of 4 components type.
Definition: fwd.hpp:290
glm::uint8_t
uint8 uint8_t
Default qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:101
glm::mediump_i8vec1
vec< 1, i8, mediump > mediump_i8vec1
Medium qualifier 8 bit signed integer scalar type.
Definition: fwd.hpp:227
glm::mediump_int32_t
int32 mediump_int32_t
Medium qualifier 32 bit signed integer type.
Definition: fwd.hpp:69
glm::highp_float32_t
float highp_float32_t
High 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:159
glm::f32mat3x3
mat< 3, 3, f32, defaultp > f32mat3x3
Single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:704
glm::highp_u8
uint8 highp_u8
High qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:91
glm::mediump_uint8
uint8 mediump_uint8
Medium qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:95
glm::highp_fmat4x2
mat< 4, 2, f32, highp > highp_fmat4x2
High single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:656
glm::highp_f32vec2
vec< 2, f32, highp > highp_f32vec2
High single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:457
glm::mediump_int64_t
int64 mediump_int64_t
Medium qualifier 64 bit signed integer type.
Definition: fwd.hpp:83
glm::lowp_u64vec3
vec< 3, u64, lowp > lowp_u64vec3
Low qualifier 64 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:386
glm::highp_f64mat2x2
mat< 2, 2, f64, highp > highp_f64mat2x2
High double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:770
glm::highp_u32vec3
vec< 3, u32, highp > highp_u32vec3
High qualifier 32 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:376
glm::highp_int8_t
int8 highp_int8_t
High qualifier 8 bit signed integer type.
Definition: fwd.hpp:42
glm::lowp_f32quat
qua< f32, lowp > lowp_f32quat
Low single-qualifier floating-point quaternion.
Definition: fwd.hpp:802
glm::lowp_i32vec4
vec< 4, i32, lowp > lowp_i32vec4
Low qualifier 32 bit signed integer vector of 4 components type.
Definition: fwd.hpp:265
glm::highp_i16vec1
vec< 1, i16, highp > highp_i16vec1
High qualifier 16 bit signed integer scalar type.
Definition: fwd.hpp:252
glm::lowp_fmat4x4
mat< 4, 4, f32, lowp > lowp_fmat4x4
Low single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:638
glm::f32mat3x2
mat< 3, 2, f32, defaultp > f32mat3x2
Single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:701
glm::lowp_f32mat3x3
mat< 3, 3, f32, lowp > lowp_f32mat3x3
Low single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:674
glm::lowp_i8vec2
vec< 2, i8, lowp > lowp_i8vec2
Low qualifier 8 bit signed integer vector of 2 components type.
Definition: fwd.hpp:223
glm::i32vec4
vec< 4, i32, defaultp > i32vec4
32 bit signed integer vector of 4 components type.
Definition: fwd.hpp:280
glm::highp_f32mat2
mat< 2, 2, f32, highp > highp_f32mat2
High single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:548
glm::lowp_f32
float lowp_f32
Low 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:147
glm::mediump_u16vec4
vec< 4, u16, mediump > mediump_u16vec4
Medium qualifier 16 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:352
glm::u32vec3
vec< 3, u32, defaultp > u32vec3
Default qualifier 32 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:381
glm::u8vec2
vec< 2, u8, defaultp > u8vec2
Default qualifier 8 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:340
glm::mediump_i16
int16 mediump_i16
Medium qualifier 16 bit signed integer type.
Definition: fwd.hpp:46
glm::highp_u64vec2
vec< 2, u64, highp > highp_u64vec2
High qualifier 64 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:395
glm::i8vec3
vec< 3, i8, defaultp > i8vec3
8 bit signed integer vector of 3 components type.
Definition: fwd.hpp:239
glm::mediump_f32mat2x2
mat< 2, 2, f32, mediump > mediump_f32mat2x2
High single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:680
glm::mediump_uint16_t
uint16 mediump_uint16_t
Medium qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:113
glm::mediump_f64mat4x3
mat< 4, 3, f64, mediump > mediump_f64mat4x3
Medium double-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:767
glm::u8vec3
vec< 3, u8, defaultp > u8vec3
Default qualifier 8 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:341
glm::highp_f64
double highp_f64
High 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:165
glm::mediump_fvec3
vec< 3, float, mediump > mediump_fvec3
Medium Single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:433
glm::mediump_int64
int64 mediump_int64
Medium qualifier 64 bit signed integer type.
Definition: fwd.hpp:79
glm::mediump_u64vec4
vec< 4, u64, mediump > mediump_u64vec4
Medium qualifier 64 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:392
glm::uint64_t
uint64 uint64_t
Default qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:143
glm::highp_u32vec2
vec< 2, u32, highp > highp_u32vec2
High qualifier 32 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:375
glm::highp_fvec1
vec< 1, float, highp > highp_fvec1
High single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:436
glm::lowp_i64vec4
vec< 4, i64, lowp > lowp_i64vec4
Low qualifier 64 bit signed integer vector of 4 components type.
Definition: fwd.hpp:285
glm::i32vec3
vec< 3, i32, defaultp > i32vec3
32 bit signed integer vector of 3 components type.
Definition: fwd.hpp:279
glm::highp_f32mat2x4
mat< 2, 4, f32, highp > highp_f32mat2x4
High single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:692
glm::lowp_i8vec1
vec< 1, i8, lowp > lowp_i8vec1
Low qualifier 8 bit signed integer scalar type.
Definition: fwd.hpp:222
glm::highp_f64mat2
mat< 2, 2, f64, highp > highp_f64mat2
High double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:580
glm::lowp_uint16_t
uint16 lowp_uint16_t
Low qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:112
glm::highp_f64mat3x2
mat< 3, 2, f64, highp > highp_f64mat3x2
High double-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:773
glm::mediump_u32vec3
vec< 3, u32, mediump > mediump_u32vec3
Medium qualifier 32 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:371
glm::lowp_uint16
uint16 lowp_uint16
Low qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:108
glm::highp_u8vec3
vec< 3, u8, highp > highp_u8vec3
High qualifier 8 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:336
glm::f64vec4
vec< 4, f64, defaultp > f64vec4
Double-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:504
glm::highp_i8vec2
vec< 2, i8, highp > highp_i8vec2
High qualifier 8 bit signed integer vector of 2 components type.
Definition: fwd.hpp:233
glm::lowp_i32vec3
vec< 3, i32, lowp > lowp_i32vec3
Low qualifier 32 bit signed integer vector of 3 components type.
Definition: fwd.hpp:264
glm::lowp_i32
int32 lowp_i32
Low qualifier 32 bit signed integer type.
Definition: fwd.hpp:59
glm::mediump_fmat4x4
mat< 4, 4, f32, mediump > mediump_fmat4x4
Medium single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:648
glm::mediump_i64
int64 mediump_i64
Medium qualifier 64 bit signed integer type.
Definition: fwd.hpp:74
glm::lowp_i16vec4
vec< 4, i16, lowp > lowp_i16vec4
Low qualifier 16 bit signed integer vector of 4 components type.
Definition: fwd.hpp:245
glm::highp_f64mat4x3
mat< 4, 3, f64, highp > highp_f64mat4x3
High double-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:777
glm::highp_u8vec2
vec< 2, u8, highp > highp_u8vec2
High qualifier 8 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:335
glm::highp_i8vec3
vec< 3, i8, highp > highp_i8vec3
High qualifier 8 bit signed integer vector of 3 components type.
Definition: fwd.hpp:234
glm::highp_f64vec3
vec< 3, f64, highp > highp_f64vec3
High double-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:498
glm::fvec2
vec< 2, f32, defaultp > fvec2
Single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:442
glm::lowp_f64vec4
vec< 4, f64, lowp > lowp_f64vec4
Low double-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:489
glm::mediump_f32vec3
vec< 3, f32, mediump > mediump_f32vec3
Medium single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:453
glm::lowp_f64
double lowp_f64
Low 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:163
glm::lowp_fmat4x2
mat< 4, 2, f32, lowp > lowp_fmat4x2
Low single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:636
glm::highp_f64mat2x4
mat< 2, 4, f64, highp > highp_f64mat2x4
High double-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:772
glm::highp_f64mat4
mat< 4, 4, f64, highp > highp_f64mat4
High double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:582
glm::mediump_i32vec4
vec< 4, i32, mediump > mediump_i32vec4
Medium qualifier 32 bit signed integer vector of 4 components type.
Definition: fwd.hpp:270
glm::lowp_f32mat2
mat< 2, 2, f32, lowp > lowp_f32mat2
Low single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:540
glm::int16_t
int16 int16_t
16 bit signed integer type.
Definition: fwd.hpp:57
glm::highp_i64
int64 highp_i64
High qualifier 64 bit signed integer type.
Definition: fwd.hpp:75
glm::highp_f64mat3x4
mat< 3, 4, f64, highp > highp_f64mat3x4
High double-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:775
glm::highp_fmat3
mat< 3, 3, f32, highp > highp_fmat3
High single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:533
glm::mediump_f32mat3x3
mat< 3, 3, f32, mediump > mediump_f32mat3x3
Medium single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:684
glm::mediump_f64quat
qua< f64, mediump > mediump_f64quat
Medium double-qualifier floating-point quaternion.
Definition: fwd.hpp:813
glm::int32_t
int32 int32_t
32 bit signed integer type.
Definition: fwd.hpp:71
glm::f64vec2
vec< 2, f64, defaultp > f64vec2
Double-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:502
glm::lowp_uint64_t
uint64 lowp_uint64_t
Low qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:140
glm::uint64
detail::uint64 uint64
64 bit unsigned integer type.
Definition: scalar_uint_sized.hpp:67
glm::highp_int16
int16 highp_int16
High qualifier 16 bit signed integer type.
Definition: fwd.hpp:52
glm::mediump_i16vec1
vec< 1, i16, mediump > mediump_i16vec1
Medium qualifier 16 bit signed integer scalar type.
Definition: fwd.hpp:247
glm::fmat2x4
mat< 2, 4, f32, defaultp > fmat2x4
Single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:666
glm::highp_fmat2x2
mat< 2, 2, f32, highp > highp_fmat2x2
High single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:650
glm::highp_fvec4
vec< 4, float, highp > highp_fvec4
High Single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:439
glm::highp_f64mat3x3
mat< 3, 3, f64, highp > highp_f64mat3x3
High double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:774
glm::mediump_i32
int32 mediump_i32
Medium qualifier 32 bit signed integer type.
Definition: fwd.hpp:60
glm::lowp_u16vec2
vec< 2, u16, lowp > lowp_u16vec2
Low qualifier 16 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:345
glm::highp_u32vec4
vec< 4, u32, highp > highp_u32vec4
High qualifier 32 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:377
glm::lowp_float32_t
float lowp_float32_t
Low 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:157
glm::highp_uint64_t
uint64 highp_uint64_t
High qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:142
glm::lowp_f32vec2
vec< 2, f32, lowp > lowp_f32vec2
Low single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:447
glm::u32vec4
vec< 4, u32, defaultp > u32vec4
Default qualifier 32 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:382
glm::mediump_f64mat2
mat< 2, 2, f64, mediump > mediump_f64mat2
Medium double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:576
glm::highp_f32mat4x3
mat< 4, 3, f32, highp > highp_f32mat4x3
High single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:697
glm::f32quat
qua< f32, defaultp > f32quat
Single-qualifier floating-point quaternion.
Definition: fwd.hpp:805
glm::int64
detail::int64 int64
64 bit signed integer type.
Definition: scalar_int_sized.hpp:67
glm::highp_u64vec1
vec< 1, u64, highp > highp_u64vec1
High qualifier 64 bit unsigned integer scalar type.
Definition: fwd.hpp:394
glm::highp_f64mat2x3
mat< 2, 3, f64, highp > highp_f64mat2x3
High double-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:771
glm::lowp_i8vec4
vec< 4, i8, lowp > lowp_i8vec4
Low qualifier 8 bit signed integer vector of 4 components type.
Definition: fwd.hpp:225
glm::lowp_fmat4x3
mat< 4, 3, f32, lowp > lowp_fmat4x3
Low single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:637
glm::f32
float f32
Default 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:150
glm::highp_i32vec2
vec< 2, i32, highp > highp_i32vec2
High qualifier 32 bit signed integer vector of 2 components type.
Definition: fwd.hpp:273
glm::mediump_u8vec1
vec< 1, u8, mediump > mediump_u8vec1
Medium qualifier 8 bit unsigned integer scalar type.
Definition: fwd.hpp:329
glm::highp_fmat4x3
mat< 4, 3, f32, highp > highp_fmat4x3
High single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:657
glm::mediump_i16vec4
vec< 4, i16, mediump > mediump_i16vec4
Medium qualifier 16 bit signed integer vector of 4 components type.
Definition: fwd.hpp:250
glm::f64mat4x2
mat< 4, 2, f64, defaultp > f64mat4x2
Double-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:782
glm::fmat2x3
mat< 2, 3, f32, defaultp > fmat2x3
Single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:663
glm::mediump_f64mat4
mat< 4, 4, f64, mediump > mediump_f64mat4
Medium double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:578
glm::mediump_u8vec4
vec< 4, u8, mediump > mediump_u8vec4
Medium qualifier 8 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:332
glm::lowp_f32mat3x4
mat< 3, 4, f32, lowp > lowp_f32mat3x4
Low single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:675
glm::mediump_float64_t
double mediump_float64_t
Medium 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:174
glm::highp_fvec2
vec< 2, float, highp > highp_fvec2
High Single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:437
glm::u16
uint16 u16
Default qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:106
glm::lowp_i64
int64 lowp_i64
Low qualifier 64 bit signed integer type.
Definition: fwd.hpp:73
glm::f32mat4
mat< 4, 4, f32, defaultp > f32mat4
Single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:554
glm::mediump_fmat4x2
mat< 4, 2, f32, mediump > mediump_fmat4x2
Medium single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:646
glm::lowp_f64mat2
mat< 2, 2, f64, lowp > lowp_f64mat2
Low double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:572
glm::mediump_int8_t
int8 mediump_int8_t
Medium qualifier 8 bit signed integer type.
Definition: fwd.hpp:41
glm::lowp_fmat3x3
mat< 3, 3, f32, lowp > lowp_fmat3x3
Low single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:634
glm::lowp_float64_t
double lowp_float64_t
Low 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:173
glm::highp_int16_t
int16 highp_int16_t
High qualifier 16 bit signed integer type.
Definition: fwd.hpp:56
glm::highp_fmat3x3
mat< 3, 3, f32, highp > highp_fmat3x3
High single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:654
glm::i64vec1
vec< 1, i64, defaultp > i64vec1
64 bit signed integer scalar type.
Definition: fwd.hpp:297
glm::lowp_u32
uint32 lowp_u32
Low qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:117
glm::lowp_u8vec1
vec< 1, u8, lowp > lowp_u8vec1
Low qualifier 8 bit unsigned integer scalar type.
Definition: fwd.hpp:324
glm::mediump_i64vec3
vec< 3, i64, mediump > mediump_i64vec3
Medium qualifier 64 bit signed integer vector of 3 components type.
Definition: fwd.hpp:289
glm::highp_f32quat
qua< f32, highp > highp_f32quat
High single-qualifier floating-point quaternion.
Definition: fwd.hpp:804
glm::highp_u16
uint16 highp_u16
High qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:105
glm::fvec1
vec< 1, f32, defaultp > fvec1
Single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:441
glm::mediump_u8vec2
vec< 2, u8, mediump > mediump_u8vec2
Medium qualifier 8 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:330
glm::lowp_int32_t
int32 lowp_int32_t
Low qualifier 32 bit signed integer type.
Definition: fwd.hpp:68
glm::lowp_u16vec1
vec< 1, u16, lowp > lowp_u16vec1
Low qualifier 16 bit unsigned integer scalar type.
Definition: fwd.hpp:344
glm::highp_fmat4x4
mat< 4, 4, f32, highp > highp_fmat4x4
High single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:658
glm::highp_f32mat3x4
mat< 3, 4, f32, highp > highp_f32mat3x4
High single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:695
glm::f32vec2
vec< 2, f32, defaultp > f32vec2
Single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:462
glm::highp_u16vec3
vec< 3, u16, highp > highp_u16vec3
High qualifier 16 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:356
glm::mediump_float32_t
float mediump_float32_t
Medium 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:158
glm::fmat2x2
mat< 2, 2, f32, defaultp > fmat2x2
Single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:660
glm::mediump_f32
float mediump_f32
Medium 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:148
glm::mediump_f32mat4x4
mat< 4, 4, f32, mediump > mediump_f32mat4x4
Medium single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:688
glm::mediump_f32vec2
vec< 2, f32, mediump > mediump_f32vec2
Medium single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:452
glm::lowp_int8
int8 lowp_int8
Low qualifier 8 bit signed integer type.
Definition: fwd.hpp:36
glm::lowp_f64vec1
vec< 1, f64, lowp > lowp_f64vec1
Low double-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:486
glm::highp_f32mat3x2
mat< 3, 2, f32, highp > highp_f32mat3x2
High single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:693
glm::mediump_f64mat3x2
mat< 3, 2, f64, mediump > mediump_f64mat3x2
Medium double-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:763
glm::mediump_u8vec3
vec< 3, u8, mediump > mediump_u8vec3
Medium qualifier 8 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:331
glm::lowp_f64mat4x4
mat< 4, 4, f64, lowp > lowp_f64mat4x4
Low double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:758
glm::lowp_i16vec1
vec< 1, i16, lowp > lowp_i16vec1
Low qualifier 16 bit signed integer scalar type.
Definition: fwd.hpp:242
glm::lowp_int8_t
int8 lowp_int8_t
Low qualifier 8 bit signed integer type.
Definition: fwd.hpp:40
glm::lowp_u32vec2
vec< 2, u32, lowp > lowp_u32vec2
Low qualifier 32 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:365
glm::mediump_f32mat2x4
mat< 2, 4, f32, mediump > mediump_f32mat2x4
Medium single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:682
glm::f64mat4x3
mat< 4, 3, f64, defaultp > f64mat4x3
Double-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:785
glm::highp_i64vec2
vec< 2, i64, highp > highp_i64vec2
High qualifier 64 bit signed integer vector of 2 components type.
Definition: fwd.hpp:293
glm::mediump_f32mat4
mat< 4, 4, f32, mediump > mediump_f32mat4
Medium single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:546
glm::i64
int64 i64
64 bit signed integer type.
Definition: fwd.hpp:76
glm::f64
double f64
Default 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:166
glm::mediump_f32vec1
vec< 1, f32, mediump > mediump_f32vec1
Medium single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:451
glm::mediump_f32mat3x4
mat< 3, 4, f32, mediump > mediump_f32mat3x4
Medium single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:685
glm::highp_fmat2
mat< 2, 2, f32, highp > highp_fmat2
High single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:532
glm::highp_f32vec3
vec< 3, f32, highp > highp_f32vec3
High single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:458
glm::mediump_i8vec4
vec< 4, i8, mediump > mediump_i8vec4
Medium qualifier 8 bit signed integer vector of 4 components type.
Definition: fwd.hpp:230
glm::lowp_float32
float lowp_float32
Low 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:152
glm::u32vec2
vec< 2, u32, defaultp > u32vec2
Default qualifier 32 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:380
glm::mediump_fvec4
vec< 4, float, mediump > mediump_fvec4
Medium Single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:434
glm::mediump_int32
int32 mediump_int32
Medium qualifier 32 bit signed integer type.
Definition: fwd.hpp:65
glm::i64vec2
vec< 2, i64, defaultp > i64vec2
64 bit signed integer vector of 2 components type.
Definition: fwd.hpp:298
glm::i16
int16 i16
16 bit signed integer type.
Definition: fwd.hpp:48
glm::fmat4x4
mat< 4, 4, f32, defaultp > fmat4x4
Single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:668
glm::lowp_f64quat
qua< f64, lowp > lowp_f64quat
Low double-qualifier floating-point quaternion.
Definition: fwd.hpp:812
glm::fmat3x2
mat< 3, 2, f32, defaultp > fmat3x2
Single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:661
glm::u16vec4
vec< 4, u16, defaultp > u16vec4
Default qualifier 16 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:362
glm::u16vec2
vec< 2, u16, defaultp > u16vec2
Default qualifier 16 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:360
glm::mediump_u8
uint8 mediump_u8
Medium qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:90
glm::lowp_fmat2x2
mat< 2, 2, f32, lowp > lowp_fmat2x2
Low single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:630
glm::highp_i8vec4
vec< 4, i8, highp > highp_i8vec4
High qualifier 8 bit signed integer vector of 4 components type.
Definition: fwd.hpp:235
glm::lowp_u64vec4
vec< 4, u64, lowp > lowp_u64vec4
Low qualifier 64 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:387
glm::mediump_i64vec2
vec< 2, i64, mediump > mediump_i64vec2
Medium qualifier 64 bit signed integer vector of 2 components type.
Definition: fwd.hpp:288
glm::highp_f64mat4x2
mat< 4, 2, f64, highp > highp_f64mat4x2
High double-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:776
glm::mediump_int16_t
int16 mediump_int16_t
Medium qualifier 16 bit signed integer type.
Definition: fwd.hpp:55
glm::lowp_i8
int8 lowp_i8
Low qualifier 8 bit signed integer type.
Definition: fwd.hpp:31
glm::i64vec3
vec< 3, i64, defaultp > i64vec3
64 bit signed integer vector of 3 components type.
Definition: fwd.hpp:299
glm::lowp_i32vec2
vec< 2, i32, lowp > lowp_i32vec2
Low qualifier 32 bit signed integer vector of 2 components type.
Definition: fwd.hpp:263
glm::highp_f64quat
qua< f64, highp > highp_f64quat
High double-qualifier floating-point quaternion.
Definition: fwd.hpp:814
glm::mediump_f64vec2
vec< 2, f64, mediump > mediump_f64vec2
Medium double-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:492
glm::highp_uint16_t
uint16 highp_uint16_t
High qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:114
glm::lowp_fvec1
vec< 1, float, lowp > lowp_fvec1
Low single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:426
glm::i8
int8 i8
8 bit signed integer type.
Definition: fwd.hpp:34
glm::mediump_uint64_t
uint64 mediump_uint64_t
Medium qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:141
glm::mediump_u64vec1
vec< 1, u64, mediump > mediump_u64vec1
Medium qualifier 64 bit unsigned integer scalar type.
Definition: fwd.hpp:389
glm::mediump_f32mat2
mat< 2, 2, f32, mediump > mediump_f32mat2
Medium single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:544
glm::mediump_uint8_t
uint8 mediump_uint8_t
Medium qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:99
glm
Definition: common.hpp:20
glm::mediump_f64
double mediump_f64
Medium 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:164
glm::mediump_fvec1
vec< 1, float, mediump > mediump_fvec1
Medium single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:431
glm::mediump_uint16
uint16 mediump_uint16
Medium qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:109
glm::highp_u8vec4
vec< 4, u8, highp > highp_u8vec4
High qualifier 8 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:337